@@ -118,8 +118,8 @@ def fetch_ligo_strain(gps, span=120):
         IFO = os.environ['IFO']
     except KeyError:
         exit("IFO environment variable must be specified.")
-    C00 = f'{IFO}:GDS-CALIB_STRAIN'
-    C01 = f'{IFO}:DCS-CALIB_STRAIN_C01'
+    C00 = f'{IFO}:GDS-CALIB_STRAIN_CLEAN'
+    C01 = f'{IFO}:DCS-CALIB_STRAIN_CLEAN_C01'
     FREQ_CUTOFF = (10, 5e3)
 
     channel = C00
