@@ -11,7 +11,7 @@ import collections
 try:
     from termcolor import cprint
 except ImportError:
-    def cprint(text, **kwargs):
+    def cprint(text, *args, **kwargs):
         print(text)
 
 from .. import logger
@@ -36,6 +36,7 @@ IFOS = collections.OrderedDict([
     ('O2', 'asd'),
     ('O3', 'asd'),
     ('Voyager', 'psd'),
+    #('CE', 'asd'),
     ('CE1', 'psd'),
     ('CE2', 'psd'),
 ])
@@ -84,7 +85,7 @@ def git_rev_resolve_hash(git_rev):
     """Resolve a git revision into its hash string."""
     proc = git_cmd('show', '-s', '--format=format:%H', git_rev)
     if proc:
-        return proc.stdout
+        return proc.stdout.splitlines()[-1]
     else:
         return
 
@@ -125,7 +126,7 @@ def ranges_git(gitpath, ifopath, stype, **kwargs):
     return json.loads(proc.stdout)
 
 
-def ranges_dt(ifopath, **kwargs):
+def ranges_dt(ifopath, stype, **kwargs):
     """Load cached output from distance_tool [ref]"""
     import yaml
     with open(test_path('compare.yaml')) as f:
@@ -133,7 +134,7 @@ def ranges_dt(ifopath, **kwargs):
     rd = compare[os.path.basename(ifopath)]
     m1 = kwargs['m1']
     m2 = kwargs['m2']
-    assert m1 == m2
+    #assert m1 == m2
     dt = rd[m1]
     params = {
         'approximant': dt['approximant'],
@@ -186,7 +187,7 @@ $ python3 -m inspiral_range.test --git-rev remote/dev-branch
 or if you have uncommitted changes compare against the current head
 with:
 
-$ python3 -m gwinc.test --head
+$ python3 -m inspiral_range.test --head
 
 See gitrevisions(7) for various ways to refer to git revisions.
 """,
@@ -204,6 +205,9 @@ See gitrevisions(7) for various ways to refer to git revisions.
     rgroup.add_argument(
         '-dt', action='store_true',
         help="compare against cache of distance_tool output'")
+    parser.add_argument(
+        '-f', '--fast-fail', action='store_true',
+        help="return immediately on first failure'")
     parser.add_argument(
         'ifos', metavar='IFO', nargs='*', default=IFOS.keys(),
         help="specific IFO to test")
@@ -229,7 +233,6 @@ See gitrevisions(7) for various ways to refer to git revisions.
             logger.warning("git hash: {}".format(git_hash))
             git_path = test_path('rev')
             git_extract_hash(git_hash, git_path)
-            logger.warning('')
         except SystemExit as e:
             logger.error(e)
             sys.exit("Try running with '-dt' option.")
@@ -249,7 +252,7 @@ See gitrevisions(7) for various ways to refer to git revisions.
         stype = IFOS[ifo]
         path = test_path(ifo+'.txt')
 
-        print('\n\n{} {}\n'.format(ifo, path))
+        print('\n\n{} {}'.format(ifo, path))
 
         data = np.loadtxt(path)
         freq = data[:, 0]
@@ -260,6 +263,8 @@ See gitrevisions(7) for various ways to refer to git revisions.
         for m1, m2 in MASSES:
             cfail = False
 
+            print()
+
             tstring = '{}/{}'.format(m1, m2)
             print(hfmt.format(
                 tstring, label, 'current', '%d'))
@@ -269,27 +274,42 @@ See gitrevisions(7) for various ways to refer to git revisions.
             try:
                 out_ref = ranges_ref(path, stype, m1=m1, m2=m2)
                 metrics_ref = out_ref['metrics']
+            except KeyError:
+                cprint("IFO or masses not supported in reference.", 'yellow')
+                continue
             except Exception as e:
                 cfail = True
                 metrics_ref = METRICS_FAIL
                 cprint("ERROR: in ref calculation:", 'red')
-                cprint(e, 'magenta')
+                cprint(traceback.format_exc(), 'magenta')
+                # continue here because all_ranges requires the ref waveform info
+                continue
 
             try:
-                metrics_cur, H = all_ranges(freq, psd, m1=m1, m2=m2)
+                metrics_cur, H = all_ranges(freq, psd, algo='lalsimulation', **out_ref['waveform'])
             except Exception as e:
                 cfail = True
                 metrics_cur = METRICS_FAIL
                 cprint("ERROR: in cur calculation:", 'red')
                 cprint(traceback.format_exc(), 'magenta')
 
+            fail |= cfail
+            if cfail and args.fast_fail:
+                break
+
             cok = check_diff(metrics_ref, metrics_cur, fmt=fmt)
 
-            fail |= cfail
             if not cfail:
                 ok &= cok
-            print()
+            if not cok and args.fast_fail:
+                break
 
+        else:
+            continue
+        break
+
+    if fail or not ok:
+        print()
     if not ok:
         cprint(f"ERROR: Differences greater than {PD_THRESHOLD}% detected.", 'red')
     if fail:
